@@ -1,3 +1,3 @@
 from .github_data_repo import get_data_from_github
 from .github_data_repo import GitHubDataRepo
-from .github_data_repo import defult_containing_dir
+from .github_data_repo import default_containing_dir
